# MBASIC Electronics Programs

Hardware interfacing and electronics tools

## Available Electronics

### 555-Ic



**Year:** 1980s
**Tags:** 

**[Download 555-ic.bas](555-ic.bas)**

---

### 567-Ic



**Year:** 1980s
**Tags:** 

**[Download 567-ic.bas](567-ic.bas)**

---

### Atten



**Year:** 1980s
**Tags:** 

**[Download atten.bas](atten.bas)**

---

### Bc2



**Year:** 1980s
**Tags:** 

**[Download bc2.bas](bc2.bas)**

---

### Bearing



**Year:** 1980s
**Tags:** 

**[Download bearing.bas](bearing.bas)**

---

### Lst8085



**Year:** 1980s
**Tags:** 

**[Download lst8085.bas](lst8085.bas)**

---

### Lstintel



**Year:** 1980s
**Tags:** 

**[Download lstintel.bas](lstintel.bas)**

---

### Lsttdl



**Year:** 1980s
**Tags:** 

**[Download lsttdl.bas](lsttdl.bas)**

---

### Tab8085



**Year:** 1980s
**Tags:** 

**[Download tab8085.bas](tab8085.bas)**

---

### Tabintel



**Year:** 1980s
**Tags:** 

**[Download tabintel.bas](tabintel.bas)**

---

### Tabtdl



**Year:** 1980s
**Tags:** 

**[Download tabtdl.bas](tabtdl.bas)**

---

### Tabzilog



**Year:** 1980s
**Tags:** 

**[Download tabzilog.bas](tabzilog.bas)**

---

### Timer555



**Year:** 1980s
**Tags:** 

**[Download timer555.bas](timer555.bas)**

---

## How to Use

1. **Download** the .bas file you want to use
2. **Open MBASIC** in your preferred UI (Web, Tkinter, Curses, or CLI)
3. **Load the file:**
   - **Web/Tkinter UI:** Click File → Open, select the downloaded file
   - **CLI:** Type `LOAD "filename.bas"`
4. **Run:** Type `RUN` or press the Run button

## About These Electronics

These programs are from the CP/M and early PC era (1970s-1980s), 
preserved from historical archives including OAK, Simtel, and CP/M CD-ROMs.
